codestar-maze
=============

Simple maze generators in python.

Usage
-----
Installing the package also installs the `maze-gen` entry point.

::

    usage: maze-gen [-h] [--file FILE] {growing_tree} ...

    positional arguments:
      {growing_tree}  sub-command help

    options:
      -h, --help      show this help message and exit
      --file FILE

